Welcome to mirror list, hosted at ThFree Co, Russian Federation.

gitlab.com/gitlab-org/gitlab-foss.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'spec/support/helpers/stub_configuration.rb')
-rw-r--r--spec/support/helpers/stub_configuration.rb6
1 files changed, 3 insertions, 3 deletions
diff --git a/spec/support/helpers/stub_configuration.rb b/spec/support/helpers/stub_configuration.rb
index 2a7b36a4c00..4c997aceeee 100644
--- a/spec/support/helpers/stub_configuration.rb
+++ b/spec/support/helpers/stub_configuration.rb
@@ -102,7 +102,7 @@ module StubConfiguration
messages[storage_name] = Gitlab::GitalyClient::StorageSettings.new(storage_hash.to_h)
end
- allow(Gitlab.config.repositories).to receive(:storages).and_return(Settingslogic.new(messages))
+ allow(Gitlab.config.repositories).to receive(:storages).and_return(::GitlabSettings::Options.build(messages))
end
def stub_sentry_settings(enabled: true)
@@ -175,11 +175,11 @@ module StubConfiguration
end
end
# Support nested hashes by converting all values into Settingslogic objects
def to_settings(hash)
hash.transform_values do |value|
if value.is_a? Hash
- Settingslogic.new(value.to_h.deep_stringify_keys)
+ ::GitlabSettings::Options.build(value)
else
value
end
@@ -175,11 +175,11 @@ module StubConfiguration
end
end
- # Support nested hashes by converting all values into Settingslogic objects
+ # Support nested hashes by converting all values into GitlabSettings::Objects objects
def to_settings(hash)
hash.transform_values do |value|